@@ -65,7 +65,8 @@ SINGLE_OPTIONS = (
 	'Architecture',
 	'XferCommand',
 	'CleanMethod',
-	'SigLevel'
+	'SigLevel',
+	'LocalFileSigLevel'
 )
 
 BOOLEAN_OPTIONS = (
@@ -75,7 +76,8 @@ BOOLEAN_OPTIONS = (
 	'TotalDownload',
 	'CheckSpace',
 	'VerbosePkgLists',
-	'ILoveCandy'
+	'ILoveCandy',
+	'Color'
 )
 
 def pacman_conf_enumerator(path):
