@@ -92,6 +92,8 @@ void pyalpm_eventcb(alpm_event_t event, void* data1, void *data2) {
     case ALPM_EVENT_INTEGRITY_DONE:
       eventstr = "Done checking integrity";
       break;
+    case ALPM_EVENT_LOAD_START:
+    case ALPM_EVENT_LOAD_DONE:
     case ALPM_EVENT_DELTA_INTEGRITY_START:
     case ALPM_EVENT_DELTA_INTEGRITY_DONE:
     case ALPM_EVENT_DELTA_PATCHES_START:
@@ -112,6 +114,12 @@ void pyalpm_eventcb(alpm_event_t event, void* data1, void *data2) {
     case ALPM_EVENT_DISKSPACE_DONE:
       eventstr = "Done checking disk space";
       break;
+    case ALPM_EVENT_OPTDEP_REQUIRED:
+    case ALPM_EVENT_DATABASE_MISSING:
+    case ALPM_EVENT_KEYRING_START:
+    case ALPM_EVENT_KEYRING_DONE:
+    case ALPM_EVENT_KEY_DOWNLOAD_START:
+    case ALPM_EVENT_KEY_DOWNLOAD_DONE:
     default:
       eventstr = "unknown event";
   }
@@ -277,7 +285,7 @@ PyObject* pyalpm_trans_init(PyObject *self, PyObject *args, PyObject *kwargs) {
     alpm_transflag_t flag_int = 0;
     int i, ret;
     for (i = 0; i < 18; i++) {
-      if (flags[i]) flag_int |= 1 << i;
+      if (flags[i]) flag_int |= 1U << i;
     }
     ret = alpm_trans_init(handle, flag_int);
     if (ret == -1) {
